==> albert_0.27.0.orig.tar.gz: albert-0.27.0/plugins/python/i18n/python_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigWidget</name>
    <message>
        <source>The Python plugin makes the app extendable by Python modules. The built-in albert module exposes several functions and classes for use with Albert. The Python plugins are loaded from `&amp;lt;APPDATADIR&amp;gt;/python/plugins`.</source>
        <translation>Das Python-Plugin ermöglicht die Erweiterung der App durch Python-Module. Das integrierte Albert-Modul stellt mehrere Funktionen und Klassen für die Verwendung mit Albert bereit. Die Python-Plugins werden aus `&amp;lt;APPDATADIR&amp;gt;/python/plugins` geladen.</translation>
    </message>
    <message>
        <source>Open user plugin dir</source>
        <translation>Benutzerplugin-Verzeichnis öffnen</translation>
    </message>
    <message>
        <source>Open stub file</source>
        <translation>Stub-Datei öffnen</translation>
    </message>
    <message>
        <source>Open site-packages</source>
        <translation>Site-packages öffnen</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Failed initializing the interpreter: %1 %2</source>
        <translation>Initialisierung des Intrerpreters fehlgeschlagen: %1 %2</translation>
    </message>
    <message>
        <source>Failed initializing virtual environment. Exit code: %1.</source>
        <translation>Initialisierung der virtuellen Umgebung fehlgeschlagen. Rückgabewert: %1.</translation>
    </message>
    <message>
        <source>Some modules in the plugin &apos;%1&apos; were not found.

Install dependencies into the virtual environment?</source>
        <translation>Einige Module im Plugin &apos;%1&apos; wurden nicht gefunden.

Abhängigkeiten in die virtuelle Umgebung installieren?</translation>
    </message>
    <message>
        <source>No &apos;%1&apos; in $PATH.</source>
        <translation>Kein &apos;%1&apos; in $PATH.</translation>
    </message>
</context>
</TS>

==> albert_0.27.3.orig.tar.gz: albert-0.27.3/plugins/python/i18n/python_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Python version</source>
        <translation>Python-Version</translation>
    </message>
    <message>
        <source>PyBind version</source>
        <translation>PyBind-Version</translation>
    </message>
    <message>
        <source>API version</source>
        <translation>API-Version</translation>
    </message>
    <message>
        <source>Virtual environment</source>
        <translation>Virtuelle Umgebung</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>User plugin directory</source>
        <translation>Benutzerplugin-Verzeichnis</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Failed initializing the interpreter: %1 %2</source>
        <translation>Initialisierung des Intrerpreters fehlgeschlagen: %1 %2</translation>
    </message>
    <message>
        <source>Failed initializing virtual environment. Exit code: %1.</source>
        <translation>Initialisierung der virtuellen Umgebung fehlgeschlagen. Rückgabewert: %1.</translation>
    </message>
    <message>
        <source>Some modules in the plugin &apos;%1&apos; were not found.

Install dependencies into the virtual environment?</source>
        <translation>Einige Module im Plugin &apos;%1&apos; wurden nicht gefunden.

Abhängigkeiten in die virtuelle Umgebung installieren?</translation>
    </message>
    <message>
        <source>No &apos;%1&apos; in $PATH.</source>
        <translation>Kein &apos;%1&apos; in $PATH.</translation>
    </message>
    <message>
        <source>Resetting the virtual environment requires a restart.</source>
        <translation>Das Zurücksetzen der virtuellen Umgebung erfordert einen Neustart.</translation>
    </message>
</context>
</TS>
